# https://gcc.gnu.org/gcc-10/porting_to.html#common
%define _legacy_common_support 1

# Note from upstream:
# the SDL playback plugin is now deprecated in favour of the openGL playback plugin.
# For one thing the program will crash if you use the SDL plugin and projectM plugin at the same time.
# If you have both SDL 1 and SDL 2 installed, LiVES will detect both, since it will use SDL2 for projectM and SDL1 for the SDL playback plugin.
# Use 'SDL2' and 'projectM' together.
%bcond_without SDL2_projectM

%define major		0
%define libname		%mklibname weed %{major}
%define develname	%mklibname weed -d

Summary:	Linux Video Editing System
Name:		lives
Version:	3.0.2
Release:	%mkrel 8
License:	GPLv3+
Group:		Video/Editors and Converters
URL:		http://lives-video.com/
Source0:	http://lives-video.com/releases/LiVES-%{version}.tar.bz2
Patch1:		0001-Switch-to-opencv2-COLOR_RGB2GRAY.patch

BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(fftw3f)
BuildRequires:	pkgconfig(frei0r)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glee)
BuildRequires:	pkgconfig(glib-2.0) >= 2.14.0
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:	pkgconfig(libavc1394)
BuildRequires:	pkgconfig(libavcodec) >= 53.0.0
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(liboil-0.3) >= 0.3.9
BuildRequires:	pkgconfig(libpng) > 1.2.0
BuildRequires:	pkgconfig(libpulse) >= 0.9.14
BuildRequires:	pkgconfig(libraw1394)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libunicap)
BuildRequires:	pkgconfig(libvisual-0.4) >= 0.4.0
BuildRequires:	pkgconfig(mjpegtools) >= 1.6.2
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(opencv) >= 2.3.1
BuildRequires:	pkgconfig(schroedinger-1.0)
BuildRequires:  pkgconfig(libtirpc)
%if %{with SDL2_projectM}
BuildRequires:	pkgconfig(libprojectM)
BuildRequires:	pkgconfig(sdl2)
%endif
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xrender)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	bison
BuildRequires:	ladspa-devel
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(jack)
BuildRequires:	libv4l-devel
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(fftw3)
Requires:	ffmpeg
Requires:	mplayer sox imagemagick
Requires:	cdrecord-cdda2wav
Requires:	xset
Requires:	libvisual-plugins
#This are not mandatory dependencies according to README
Recommends:	cdrkit-icedax
Recommends:	dvgrab
Recommends:	frei0r
Recommends:	lame
Recommends:	ladspa
Recommends:	mkvtoolnix
Recommends:	mpv
Recommends:	vorbis-tools
Recommends:	x264
Recommends:	youtube-dl

%description
The Linux Video Editing System (LiVES) is intended to be a simple yet powerful
video effects and editing system.  It uses common tools for most of its work
(mplayer, ImageMagick, GTK+, sox).

%package -n %{libname}
Summary:	Linux Video Editing System - shared libs
Group:		Video/Editors and Converters

%description -n %{libname}
This package contains shared libs for LiVES.

%package -n %{develname}
Summary:	Linux Video Editing System - Development files
Group:		Video/Editors and Converters
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains development files needed to build LiVES plugins.

%prep
%autosetup -p1

# update manually the library paths in libweed/*.pc files on a 64 bit system
%ifarch x86_64 aarch64
sed -i 's|\${exec_prefix}/lib|\${exec_prefix}/lib64|' libweed/*.pc
%endif

%build
%define _legacy_common_support 1
%define _disable_ld_no_undefined 1
%configure \
           %if %{without SDL2_projectM}
           --disable-sdl2 --disable-projectM \
           %endif
           --enable-threads=posix
%make_build CPPFLAGS="`pkg-config --cflags libtirpc` `pkg-config --cflags opencv4`"

%install
%make_install

%find_lang %{name}

rm -fr %{buildroot}%{_datadir}/doc
rm -f %{buildroot}%{_datadir}/pixmaps/%{name}.xpm

# fix symlink
rm -rf %{buildroot}%{_bindir}/%{name}
ln -s %{_bindir}/%{name}-exe %{buildroot}%{_bindir}/%{name}

# don't ship .a or .la
find %{buildroot} -name '*.a' -delete
find %{buildroot} -name '*.la' -delete

# python shebang
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" \
  %{buildroot}%{_libdir}/lives/plugins/encoders/* \
  %{buildroot}%{_bindir}/lives_*

%files -f %{name}.lang
%doc AUTHORS C* docs/*.txt FEATURES GETTING*
%doc NEWS OMC/*.txt README RFX/*
%{_bindir}/*
%{_datadir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/LiVES.desktop
%{_datadir}/app-install/icons/lives.png
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/lives.png

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/weed
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Thu Nov 26 2020 tv <tv> 3.0.2-8.mga8
+ Revision: 1649481
- fix building with libtirpc

* Fri Oct 30 2020 joequant <joequant> 3.0.2-7.mga8
+ Revision: 1640663
- rebuild for opencv

* Sun Jun 28 2020 joequant <joequant> 3.0.2-6.mga8
+ Revision: 1599914
- fix gcc10 build

* Fri Jun 05 2020 daviddavid <daviddavid> 3.0.2-5.mga8
+ Revision: 1590526
- fix library paths in all libweed/*.pc files for 64 bit system

* Fri Jun 05 2020 daviddavid <daviddavid> 3.0.2-4.mga8
+ Revision: 1590522
- switch to sdl2 needed for projectM
- switch to upstream patch for opencv 4 support
- fix build with gcc10
- rebuild for new libprojectm 3.1.3

* Wed Feb 19 2020 umeabot <umeabot> 3.0.2-3.mga8
+ Revision: 1544567
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 3.0.2-2.mga8
+ Revision: 1483327
- replace deprecated %%configure2_5x
+ daviddavid <daviddavid>
- add patch to fix build with opencv 4.2.0
- rebuild for new opencv 4.2.0

* Fri Nov 15 2019 zezinho <zezinho> 3.0.2-1.mga8
+ Revision: 1460752
- new version 3
- add all recommended helpers
- enable frei0r
- enable ProjectM

* Wed Jan 09 2019 zezinho <zezinho> 2.10.2-1.mga7
+ Revision: 1353834
- new bugfix version 2.10.2

* Tue Dec 25 2018 zezinho <zezinho> 2.10.1-1.mga7
+ Revision: 1344899
- new version 2.10.1
- new version 2.10.0
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Fri Apr 27 2018 daviddavid <daviddavid> 2.8.9-4.mga7
+ Revision: 1222776
- rebuild for new ffmpeg 4.0

* Fri Apr 13 2018 daviddavid <daviddavid> 2.8.9-2.mga7
+ Revision: 1218276
- rebuild for new opencv 3.4.1

* Thu Mar 15 2018 zezinho <zezinho> 2.8.9-1.mga7
+ Revision: 1209686
- new version 2.8.9

* Sun Mar 11 2018 zezinho <zezinho> 2.8.8-1.mga7
+ Revision: 1208249
- new version 2.8.8

* Mon Feb 26 2018 daviddavid <daviddavid> 2.8.7-2.mga7
+ Revision: 1205274
- remove no more needed BR libpth-devel

* Thu Sep 21 2017 zezinho <zezinho> 2.8.7-1.mga7
+ Revision: 1156741
- new version

* Tue May 02 2017 akien <akien> 2.8.4-4.mga6
+ Revision: 1098364
- Rebuild for ffmpeg 3.3

* Fri Mar 10 2017 akien <akien> 2.8.4-3.mga6
+ Revision: 1091625
- Rebuild for v4l-utils 1.12.3

* Sat Jan 21 2017 zezinho <zezinho> 2.8.4-2.mga6
+ Revision: 1082682
- rebuild for ffmpeg 3.2.x

* Mon Jan 16 2017 zezinho <zezinho> 2.8.4-1.mga6
+ Revision: 1082098
- new bugfix version 2.8.4

* Mon Jan 02 2017 zezinho <zezinho> 2.8.3-1.mga6
+ Revision: 1079808
- new version

* Tue Nov 29 2016 zezinho <zezinho> 2.8.2-1.mga6
+ Revision: 1071006
- new version

* Mon Oct 24 2016 zezinho <zezinho> 2.8.1-1.mga6
+ Revision: 1063394
- new version with security fixes for multiusers systems

* Sat Oct 15 2016 zezinho <zezinho> 2.8.0-2.mga6
+ Revision: 1060841
- requires from now ffmpeg instead of mencoder according to upstream

* Fri Sep 09 2016 zezinho <zezinho> 2.8.0-1.mga6
+ Revision: 1051081
- change icon path
- new bugfix version

* Wed May 18 2016 shlomif <shlomif> 2.6.3-1.mga6
+ Revision: 1016598
- Fix build due to a missing #include
+ zezinho <zezinho>
- new version

* Tue Mar 29 2016 zezinho <zezinho> 2.6.2-1.mga6
+ Revision: 996369
- new version

* Tue Mar 15 2016 daviddavid <daviddavid> 2.6.0-3.mga6
+ Revision: 990911
- rebuild with schroedinger without .la files

* Mon Feb 15 2016 luigiwalser <luigiwalser> 2.6.0-2.mga6
+ Revision: 961523
- rebuild for mjpegtools

* Mon Feb 01 2016 zezinho <zezinho> 2.6.0-1.mga6
+ Revision: 930591
- new version

* Mon Jan 25 2016 zezinho <zezinho> 2.4.8-1.mga6
+ Revision: 927351
- new version

* Mon Jan 18 2016 zezinho <zezinho> 2.4.7-1.mga6
+ Revision: 925478
- new version

* Sat Dec 19 2015 zezinho <zezinho> 2.4.6-1.mga6
+ Revision: 912144
- new version

* Wed Dec 02 2015 zezinho <zezinho> 2.4.5-1.mga6
+ Revision: 907748
- new version 2.4.5

* Sat Nov 28 2015 zezinho <zezinho> 2.4.4-1.mga6
+ Revision: 906800
- build witout OSC for now
- new version 2.4.4

* Sun Feb 08 2015 alexl <alexl> 2.2.7-1.mga5
+ Revision: 814170
- version 2.2.7 without crash (mga#15070)
- desktop file with GenericName and Comment
- cleanup spec

* Fri Nov 14 2014 akien <akien> 2.2.6-5.mga5
+ Revision: 797107
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 2.2.6-4.mga5
+ Revision: 744450
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.6-3.mga5
+ Revision: 681964
- Mageia 5 Mass Rebuild

* Tue Aug 26 2014 luigiwalser <luigiwalser> 2.2.6-2.mga5
+ Revision: 668369
- rebuild

* Mon Aug 18 2014 fwang <fwang> 2.2.6-1.mga5
+ Revision: 665021
- 2.2.6

* Mon Oct 21 2013 umeabot <umeabot> 2.0.6-2.mga4
+ Revision: 540926
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 fwang <fwang> 2.0.6-1.mga4
+ Revision: 494553
- new version 2.0.6

* Mon Jul 15 2013 fwang <fwang> 2.0.5-2.mga4
+ Revision: 454428
- more ffmpeg 2.0 patches
- try build with recent ffmpeg
- rebuild for new ffmpeg

* Mon Jun 17 2013 fwang <fwang> 2.0.5-1.mga4
+ Revision: 444026
- new version 2.0.5

* Mon Jun 03 2013 fwang <fwang> 2.0.4-5.mga4
+ Revision: 436007
- rebuild for new libpng

* Fri May 24 2013 fwang <fwang> 2.0.4-1.mga4
+ Revision: 425886
- new version 2.0.4

* Wed Apr 17 2013 dams <dams> 2.0.3-1.mga3
+ Revision: 410294
- new version 2.0.3

* Sat Jan 12 2013 umeabot <umeabot> 1.8.0-3.mga3
+ Revision: 358886
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 1.8.0-2.mga3
+ Revision: 341680
- rebuild for new ffmpeg

* Mon Dec 17 2012 fwang <fwang> 1.8.0-1.mga3
+ Revision: 331898
- fix str fmt
- new version 1.8.0

* Mon Oct 22 2012 fwang <fwang> 1.6.4-1.mga3
+ Revision: 309077
- update rpm group
- new version 1.6.4
- new version 1.6.3
- new version 1.6.2
- more br

* Mon Apr 16 2012 fwang <fwang> 1.6.1-3.mga2
+ Revision: 231015
- add more br

* Mon Apr 16 2012 fwang <fwang> 1.6.1-2.mga2
+ Revision: 231000
- add upstream patch on incorrect usage of brackets, to try fixing bug#5413
+ wally <wally>
- fix lives symlink

* Sun Feb 05 2012 zezinho <zezinho> 1.6.1-1.mga2
+ Revision: 205038
- fix build
- new version 1.6.1

* Fri Jan 13 2012 dams <dams> 1.4.9-1.mga2
+ Revision: 195488
- new version 1.4.9
- rediff patch

* Thu Dec 01 2011 fwang <fwang> 1.4.8-1.mga2
+ Revision: 174700
- fix str fmt
- new version 1.4.8

* Mon Nov 14 2011 dams <dams> 1.4.7-1.mga2
+ Revision: 167442
- new version 1.4.7
+ fwang <fwang>
- new version 1.4.5

* Mon Jul 18 2011 fwang <fwang> 1.4.4-2.mga2
+ Revision: 125816
- rebuild for new mjpegtools

* Sat Jun 18 2011 ahmad <ahmad> 1.4.4-1.mga2
+ Revision: 109346
- Drop xmms requires (it doesn't exist in Mageia)
- Drop gdk-pixbuf-loaders requires, it depends on old gnome libs
- Don't ship .a/.la
- Drop old/unneeded scriptlets
- imported package lives

